@@ -311,7 +311,6 @@ rMaxMahalanobis <- function(n,N,d,...,pow=1,robust=TRUE) {
 # resample = Do a new simulation rather than using the old one.
 # ...=further arguments to the covMcd-routine
 pEmpiricalMahalanobis <- function(q,N,d,...,pow=1,replicates=100,resample=FALSE,robust=TRUE) {
-  require(robustbase)
   id <- paste(deparse(list(N=N,d=d,...,replicates=replicates,robust=robust,type="EmpiricalMahalanobis")),collapse="\n")
   if( resample || is.null(s<-mget(id,gsi.pStore,ifnotfound=list(NULL))[[1]])   ) {
     s <- rEmpiricalMahalanobis(replicates,N,d,...,pow=1,robust=robust)
@@ -330,7 +329,6 @@ pEmpiricalMahalanobis <- function(q,N,d,...,pow=1,replicates=100,resample=FALSE,
 # ...=further arguments to the covMcd-routine
 
 qEmpiricalMahalanobis <- function(p,N,d,...,pow=1,replicates=100,resample=FALSE,robust=TRUE) {
-  require(robustbase)
   id <- paste(deparse(list(N=N,d=d,...,replicates=replicates,robust=robust,type="EmpiricalMahalanobis")),collapse="\n")
   if( resample || is.null(s<-mget(id,gsi.pStore,ifnotfound=list(NULL))[[1]])   ) {
     s <- rEmpiricalMahalanobis(replicates,N,d,...,pow=1,robust=robust) 
@@ -378,7 +376,6 @@ rEmpiricalMahalanobis <- function(n,N,d,...,sorted=FALSE,pow=1,robust=TRUE) {
                 }
               },
               mcd={
-                require("robustbase")
                 if( d > 1 )
                   replicate(n,sorted(sqrt(do.call("covMcd",c(list(structure(rnorm(N*d),dim=c(N,d))),params))$mah))^pow)
                 else {
@@ -404,7 +401,6 @@ rEmpiricalMahalanobis <- function(n,N,d,...,sorted=FALSE,pow=1,robust=TRUE) {
 # resample = Do a new simulation rather than using the old one.
 # ...=further arguments to the covMcd-routine
 pPortionMahalanobis <- function(q,N,d,cut,...,replicates=1000,resample=FALSE,pow=1,robust=TRUE) {
-  require(robustbase)
   id <- paste(deparse(list(N=N,d=d,...,replicates=replicates,robust=robust,type="PortionMahalanobis")),collapse="\n")
   if( resample || is.null(s<-mget(id,gsi.pStore,ifnotfound=list(NULL))[[1]])   ) {
     s <- rEmpiricalMahalanobis(replicates,N,d,...,sorted=TRUE,robust=robust)
@@ -429,7 +425,6 @@ rPortionMahalanobis <- function(n,N,d,cut,...,pow=1,robust=TRUE) {
 # resample = Do a new simulation rather than using the old one.
 # ...=further arguments to the covMcd-routine
 qPortionMahalanobis <- function(p,N,d,cut,...,replicates=1000,resample=FALSE,pow=1,robust=TRUE) {
-  require(robustbase)
   id <- paste(deparse(list(N=N,d=d,...,replicates=replicates,type="PortionMahalanobis")),collapse="\n")
   if( resample || is.null(s<-mget(id,gsi.pStore,ifnotfound=list(NULL))[[1]])   ) {
     s <- rEmpiricalMahalanobis(replicates,N,d,...,sorted=TRUE,robust=robust) 
@@ -484,7 +479,6 @@ qPortionMahalanobis <- function(p,N,d,cut,...,replicates=1000,resample=FALSE,pow
 # ...=further arguments to the covMcd-routine
 
 pQuantileMahalanobis <- function(q,N,d,p,...,replicates=1000,resample=FALSE,ulimit=TRUE,pow=1,robust=TRUE) {
-  require(robustbase)
   id <- paste(deparse(list(N=N,d=d,...,pow=pow,robust=robust,replicates=replicates,type="pQuantileMahalanobis")),collapse="\n")
   if( resample || is.null(PreSort<-mget(id,gsi.pStore,ifnotfound=list(NULL))[[1]])   ) {
     s <- rEmpiricalMahalanobis(replicates,N,d,...,pow=pow,robust=robust,sorted=TRUE)
