@@ -1,6 +1,6 @@
 
 extensiveCheck <- FALSE
-noRobustCheck  <- FALSE
+noRobustCheck  <- TRUE
 if( !noRobustCheck ) {
 ###################################################
 ### chunk number 1: Bsp1
